commit eeadd5a862a193332975902d405e01c428d115d3
Author: Akihiro Sagawa <sagawa.aki@gmail.com>
Date:   Sat Oct 11 00:16:17 2014 +0900

    kernel32/tests: Add more GetFullPathNameA tests.

diff --git a/dlls/kernel32/tests/path.c b/dlls/kernel32/tests/path.c
index 0f07ea6..6f924d9 100644
--- a/dlls/kernel32/tests/path.c
+++ b/dlls/kernel32/tests/path.c
@@ -1828,6 +1828,7 @@ static void test_GetFullPathNameA(void)
     char output[MAX_PATH], *filepart;
     DWORD ret;
     int i;
+    UINT acp;
 
     const struct
     {
@@ -1864,6 +1865,28 @@ static void test_GetFullPathNameA(void)
            "[%d] Expected GetLastError() to return 0xdeadbeef, got %u\n",
            i, GetLastError());
     }
+
+    acp = GetACP();
+    if (acp != 932)  /* != Japanese */
+        skip("Skipping DBCS GetFullPathNameA test in this codepage (%d)\n", acp);
+    else {
+        const struct dbcs_case {
+            const char input[MAX_PATH];
+            const char expected[MAX_PATH/2];
+        } testset[] = {
+            { { 'c',':','\\','a','\\',0x95,0x5c,0x97,0xa0,'.','t','x','t', 0},
+              { 0x95,0x5c,0x97,0xa0,'.','t','x','t', 0} },
+            { { 'c',':','\\',0x83,0x8f,0x83,0x43,0x83,0x93,'\\','w','i','n','e','.', 'c', 0},
+              { 'w','i','n','e','.','c', 0 } }
+        };
+        for (i = 0; i < sizeof(testset)/sizeof(testset[0]); i++) {
+            ret = GetFullPathNameA(testset[i].input, sizeof(output),
+                                   output, &filepart);
+            ok(ret, "[%d] GetFullPathName error %u\n", i, GetLastError());
+            ok(!lstrcmpA(filepart, testset[i].expected),
+               "[%d] expected %s got %s\n", i, testset[i].expected, filepart);
+        }
+    }
 }
 
 static void test_GetFullPathNameW(void)
